@@ -1,8 +1,10 @@
 from pathlib import Path
+from typing import Union
 
 from commitizen import defaults, git
 
 from .base_config import BaseConfig
+from .json_config import JsonConfig
 from .toml_config import TomlConfig
 
 
@@ -26,10 +28,13 @@ def read_cfg() -> BaseConfig:
         with open(filename, "r") as f:
             data: str = f.read()
 
-        _conf: TomlConfig
+        _conf: Union[TomlConfig, JsonConfig]
         if "toml" in filename.suffix:
             _conf = TomlConfig(data=data, path=filename)
 
+        if "json" in filename.suffix:
+            _conf = JsonConfig(data=data, path=filename)
+
         if _conf.is_empty_config:
             continue
         else:
